#!/bin/bash

if [ $# = 0 ] ; then
    echo -e "Please enter the name of a PostScript file."
    exit 1
fi

NAME=$1
# basename won't work when .ps or .eps files are not in $PWD
#PREFIX1=`basename $NAME .ps`
#PREFIX2=`basename $NAME .eps`
PREFIX1=`echo "$NAME"|sed -e 's/\.ps$//'`
PREFIX2=`echo "$NAME"|sed -e 's/\.eps$//'`

if [ -f $NAME ] ; then
    INFILE=$NAME
    if [ "$NAME" = "${PREFIX1}.ps" ] ; then
	OUTFILE=${PREFIX1}.pdf
    elif [ "$NAME" = "${PREFIX2}.eps" ] ; then
	OUTFILE=${PREFIX2}.pdf
    else
	OUTFILE=${NAME}.pdf
    fi
elif [ -f "${PREFIX1}.ps" ] ; then
    INFILE=${PREFIX1}.ps
    OUTFILE=${PREFIX1}.pdf
elif [ -f "${PREFIX1}.eps" ] ; then
    INFILE=${PREFIX1}.eps
    OUTFILE=${PREFIX1}.pdf
elif [ -f "${PREFIX2}.ps" ] ; then
    INFILE=${PREFIX2}.ps
    OUTFILE=${PREFIX2}.pdf
elif [ -f "${PREFIX2}.eps" ] ; then
    INFILE=${PREFIX2}.eps
    OUTFILE=${PREFIX2}.pdf
else
    echo "Error!\tNeither $NAME, ${NAME}.ps nor ${NAME}.eps exists."
    exit 1
fi
echo NAME $NAME
echo INFILE $INFILE
echo OUTFILE $OUTFILE
# Default page size and resolution.
# Do not need these, because of what follows.
X=612
Y=792
RESX=72
RESY=72

# Look for bounding box to define X, Y, RESX and RESY
BBOX=`grep '%%BoundingBox: ' $INFILE|head -n1`
BBOX=${BBOX:-'%%BoundingBox: 0 0 612 792'}
X=`echo $BBOX|awk '{printf "%d",$4}'`
Y=`echo $BBOX|awk '{printf "%d",$5}'`
RES=`echo $X $Y|awk '{printf "%d",sqrt($1*$2/93.5)}'`

# The definition of RES should be used when invoking 'ps2pdf' using
# -g<width>x<height> and -r<resolution>
# When using gs directly, use RES=72

#echo "Creating $OUTFILE from $INFILE; size ${X}x${Y} and RES $RES."
#gs  -dNOPAUSE -q  -g${X}x${Y}   -r$RES -sDEVICE=pdfwrite  \
# -sOutputFile=$OUTFILE -dSAFER -c .setpdfwrite -f $INFILE

echo "Creating $OUTFILE from $INFILE; size ${X}x${Y} and RES 72."

gs  -dNOPAUSE -dBATCH -q  -g${X}x${Y}   -r72 -sDEVICE=pdfwrite  \
 -sOutputFile=$OUTFILE -dSAFER -c .setpdfwrite -f $INFILE
